@@ -16,11 +16,11 @@ Data::PrintUtils - A Collection of Pretty Print routines like Data::Dumper
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =cut
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 
 =head1 SYNOPSIS
@@ -55,7 +55,7 @@ BEGIN {
     use Exporter ();
     our ($VERSION, @ISA, @EXPORT, @EXPORT_OK, %EXPORT_TAGS);
 # set the version for version checking
-    $VERSION = '0.04';
+    $VERSION = '0.05';
     @ISA = qw(Exporter);
     @EXPORT_OK = qw();
     %EXPORT_TAGS = ( ALL => [ qw!&print_pid &say_pid &formatList &formatOneLineHash &formatHash
@@ -285,7 +285,7 @@ sub formatTable
 			$x{$_} = defined $hash_ref->{$_} ? $hash_ref->{$_} : $h{UNDEF_VALUE} foreach (@List);
 			push @trimedArrayOfHashRefs, \%x;
 		}
-        $table_defn = { 
+        my $table_defn = { 
             table => { border => 0, cellpadding => 0, cellspacing => 3 },
             th => { class => 'foobar' },
             null => '&nbsp;',
